@@ -17,7 +17,7 @@ from screeninfo import get_monitors
 from kivy.properties import *
 
 
-class Content(BoxLayout):
+class ContentKivy4(BoxLayout):
     pass
 
 
@@ -112,7 +112,7 @@ class Kivy4(MDApp):
             minimum = [0.1, 0.1]
 
         self.app_name = app_name
-        self.builder_string = '''<Content>
+        self.builder_string = '''<ContentKivy4>
     orientation: "vertical"
     spacing: "12dp"
     size_hint_y: None
@@ -327,6 +327,9 @@ class Kivy4(MDApp):
         else:
             left_icons, right_icons, name = properties
 
+        self.left_icons = ListProperty(left_icons)
+        self.right_icons = ListProperty(right_icons)
+
         return f'''
 Screen:
     MDToolbar:
@@ -334,8 +337,8 @@ Screen:
         pos_hint: {{"top": 1}}
         elevation: 10
         title: "{name}"
-        right_action_items: {right_icons}
-        left_action_items: {left_icons}
+        right_action_items: {self.left_icons}
+        left_action_items: {self.right_icons}
 
     MDNavigationLayout:
         x: toolbar.height
@@ -419,8 +422,8 @@ Screen:
     def on_cancel_picker(self, instance, value):
         pass
 
-    def popup(self, title='My popup', content=Content(), cancel_text='CANCEL', okay_text='OKAY',
-              okay_func=lambda: print('yes'), cancel_func=None):
+    def popup_kivy4(self, title='My popup', content=ContentKivy4(), cancel_text='CANCEL', okay_text='OKAY',
+              okay_func=lambda *args: print('yes'), cancel_func=None):
 
         if cancel_func is None:
             cancel_func = lambda *args: self.dismiss()
@@ -454,3 +457,7 @@ Screen:
 
         except Exception as e:
             print(e)
+
+
+    def updateToolbar(self, lst):
+        self.left_icons, self.right_icons = lst
\ No newline at end of file
